{% if adaptor_field.can_edit %}<{{ adaptor_field.tag_name_cover }} class="{{ adaptor_field.classes }}">{{ adaptor_field.render_config }}{{ adaptor_field.render_value_edit }}</{{ adaptor_field.tag_name_cover }}>{% else %}{{ adaptor_field.render_value }}{% endif %}