{% if value %}
    <img src="{{ MEDIA_URL }}inplaceeditform/img/true.gif" title="{{ value }}" alt="{{ value }}"/>
{% else %}
    <img src="{{ MEDIA_URL }}inplaceeditform/img/false.gif" title="{{ value }}" alt="{{ value }}"/>
{% endif %}