{% extends  "inplaceeditform/render_media_field.html" %}

{% block media %}
    {{ block.super }}
    <script src="{{ MEDIA_URL }}inplaceeditform/js/jquery.form.js" type="text/javascript"></script>
{% endblock %}


