{% extends  "inplaceeditform/render_media_field.html" %}

{% load adminmedia %}

{% block media %}
    <script src="{% url django.views.i18n.javascript_catalog %}" type="text/javascript"></script>
    <script src="{{ ADMIN_MEDIA_PREFIX }}js/core.js" type="text/javascript"></script>
    <link href="{{ ADMIN_MEDIA_PREFIX }}css/widgets.css" rel="stylesheet" type="text/css" media="print" />
    {{ block.super }}
    <script src="/media/inplaceeditform/js/DateTimeShortcutsInitial.js" type="text/javascript"></script>
    <script type="text/javascript">
        (function($){
            $(document).ready(function () {
                function DateTimeShortcutsFinish() {
                    DateTimeShortcuts = undefined;
                    CalendarNamespace = undefined;
                    return false;
                }
                $(".applyDate").data("applyFinish", DateTimeShortcutsFinish);
                $(".cancelDate").data("cancelFinish", DateTimeShortcutsFinish);
                window.__admin_media_prefix__ = "{% filter escapejs %}{% admin_media_prefix %}{% endfilter %}";
        });
        })(jQuery);
    </script>

{% endblock %}
