{% load i18n inplace_edit %}<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="{{ LANGUAGE_CODE }}" lang="{{ LANGUAGE_CODE }}">
<head>
  <script src="https://ajax.googleapis.com/ajax/libs/jquery/1.6.2/jquery.js" type="text/javascript"></script>
  {% inplace_media %}
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
  <title>{% trans "Manage Multimedia Resources" %}</title>
</head>
<body>
  {% block page %}
  <div>
    {% block content %}
    {% endblock %}
  </div>
  {% endblock %}
</body>
</html>
