{% extends "inplaceeditform/render_field.html" %}
{% load i18n %}

{% block apply %}
    {% csrf_token %}
    <button class="applyFile {% block classapply %}{% endblock %}" title="{% trans "Apply change" %}" type="button">
        <span>
        {% trans "Save" %}
        </span>
    </button>
{% endblock %}