{% load i18n %}

{% block form %}
    <form class="inplaceeditform {{ class_inplace }}" action="{% url inplace_save %}" enctype=multipart/form-data>
        {{ field }}
        <span class="field_id" style="display:none">{{ field.auto_id }}</span>
        {% block actions %}
            {% block apply %}
                <button class="apply {% block classapply %}{% endblock %}" title="{% trans "Apply change" %}" type="button">
                    <span>
                    {% trans "Save" %}
                    </span>
                </button>
            {% endblock %}
            {% block cancel %}
                <button class="cancel {% block classcancel %}{% endblock %}" title="{% trans "Cancel change" %}" type="button">
                    <span>
                    {% trans "Cancel" %}
                    </span>
                </button>
            {% endblock %}
        {% endblock %}
    </form>
{% endblock %}