button.apply,
button.applyFile {
  background: transparent none no-repeat scroll 0pt 50%;
  border: medium none;
  cursor: pointer;
  height: 22px;
  margin: 0em 0.2em 0em 1em;
  width: 22px;
  background-image:url(/media/inplaceeditform/img/apply.gif);
}

button.apply:hover,
button.applyFile:hover {
    background: url("/media/inplaceeditform/img/apply.gif") no-repeat scroll 0 -50% transparent;
}

button.cancel {
  background: transparent none no-repeat scroll 0pt 50%;
  border: medium none;
  cursor: pointer;
  height: 22px;
  margin: 0pt 0.2em;
  width: 22px;
  background-image: url(/media/inplaceeditform/img/cancel.gif);

}

button.cancel:hover {
    background: url("/media/inplaceeditform/img/cancel.gif") no-repeat scroll 0 -50% transparent;
}

button.cancel span,
button.apply span,
button.applyFile span {
  visibility: hidden;
}

.edit_over {
  cursor: pointer; 
  background: #FFFFBB;
}

.edit_over img {
    cursor: pointer; 
    border: 2px solid #FFFFBB;
}

.errors  {
    list-style: none;
    list-style-image: none !important;
    padding: 0;
    margin: 0;
    margin-bottom: 5px;
}

.errors li {
    border: 1px solid #f57901;
    margin: 0;
    padding: 5px 5px 5px 5px;
    background-color: #fbe8d5;
    vertical-align: middle;
}

.errors img {
    text-decoration: none;
    border: none;
    vertical-align: bottom;
}

.success  {
    list-style: none;
    list-style-image: none !important;
    padding: 0;
    margin: 0;
    margin-bottom: 5px;
}

.success li {
    border: 1px solid #118811;
    margin: 0;
    padding: 5px 5px 5px 5px;
    background-color: #BAFFB2;
    color: #118811;
    vertical-align: middle;
}

.success img {
    text-decoration: none;
    border: none;
    vertical-align: bottom;
}

.missing-translation {
    display: block;
    color: red;
    text-align: center;
}

span.textareainplaceedit {
    display: block;
}

.inplaceHide {
    display: none;
}

form.inplaceeditform {
    display: inline;
}

form.inplaceeditform input[type=file] {
    margin-right: 100px;
}